@@ -16,9 +16,9 @@
 //! # fn get_tree() -> Tree {
 //! #     use tree_sitter::Parser;
 //! #     let mut parser = Parser::new();
-//! #     let lang = tree_sitter_javascript::language();
-//! #     parser.set_language(lang).expect("Error loading JavaScript grammar");
-//! #     return parser.parse("function(x) { return x * 2; }", None).expect("Error parsing provided code");
+//! #     let lang = tree_sitter_rust::language();
+//! #     parser.set_language(lang).expect("Error loading Rust grammar");
+//! #     return parser.parse("fn double(x: usize) -> usize { x * 2 }", None).expect("Error parsing provided code");
 //! # }
 //!
 //! // Non-existent method, imagine it gets a valid Tree with >1 node
@@ -417,7 +417,8 @@ mod tree_sitter_tests {
     use std::vec::Vec;
     use tree_sitter::{Parser, Tree};
 
-    const EX1: &str = r#"function double(x) {
+    const EX1: &str = r#"
+fn double(x: usize) -> usize {
     return 2 * x;
 }"#;
 
@@ -428,7 +429,7 @@ mod tree_sitter_tests {
 
 const DOUBLE = 2;
 
-function double(x) {
+function double(x: usize) -> usize {
     return DOUBLE * x;
 }"#;
 
@@ -447,13 +448,13 @@ function double(x) {
         assert_eq!(iterative_callback, iterator);
     }
 
-    /// Helper function to generate a Tree from javascript
+    /// Helper function to generate a Tree from Rust code
     fn get_tree(code: &str) -> Tree {
         let mut parser = Parser::new();
-        let lang = tree_sitter_javascript::language();
+        let lang = tree_sitter_rust::language();
         parser
             .set_language(lang)
-            .expect("Error loading JavaScript grammar");
+            .expect("Error loading Rust grammar");
         return parser
             .parse(code, None)
             .expect("Error parsing provided code");
